@@ -17,7 +17,8 @@
 Scripting SDK for the Red Team Toolkit platform
 """
 
+from rtt_sdk import exceptions  # noqa
+from rtt_sdk import models  # noqa
 from rtt_sdk.__version__ import *  # noqa
 from rtt_sdk.client import RTTClient  # noqa
-from rtt_sdk.exceptions import *  # noqa
 from rtt_sdk.slingshot import SlingshotClient  # noqa
