@@ -1,3 +1,19 @@
+# -*- coding: utf-8 -*-
+#
+# Copyright (C) 2021 NetSPI <rtt.support@netspi.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 import datetime
 from typing import TYPE_CHECKING
 
@@ -5,14 +21,17 @@ import fastapi.openapi.models
 from pydantic import BaseConfig, BaseModel, validator
 from pydantic.main import Extra
 
-if TYPE_CHECKING:
-    from dataclasses import dataclass
-else:
+RUNTIME = not TYPE_CHECKING
+if RUNTIME:
 
     def dataclass(model):
         return model
 
 
+else:
+    from dataclasses import dataclass
+
+
 autocomplete = dataclass
 
 # Allow custom field additions in schema objects (x-thing)
@@ -36,7 +55,7 @@ class Schema(BaseModel):
 
     @validator("*", pre=True)
     def not_none(cls, v, field):
-        if field.default and v is None:
+        if field.default is not None and v is None:
             return field.default
         else:
             return v
